unit Test;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DBTables, DB, StdCtrls, qiInfo, qiFormat, qiFilter, qiLookup, qiOrder,
  qiFldsEd, qiTblsEd, qiJnsEd, ExtCtrls, Buttons, qiClrsEd, qiQuery,
  qiSelect, qiGroup, MemoDlg, qiArchiv;

type
  TTestForm = class(TForm)
    LookupValueEdit: TEdit;
    OrdersTable: TTable;
    LookupFieldEdit: TEdit;
    SQLMemo: TMemo;
    UserMemo: TMemo;
    Label2: TLabel;
    Label3: TLabel;
    Label6: TLabel;
    Label7: TLabel;
    CustomersTable: TTable;
    CustomersTableCustNo: TFloatField;
    CustomersTableCompany: TStringField;
    CustomersTableAddr1: TStringField;
    CustomersTableAddr2: TStringField;
    CustomersTableCity: TStringField;
    CustomersTableState: TStringField;
    CustomersTableZip: TStringField;
    CustomersTableCountry: TStringField;
    CustomersTablePhone: TStringField;
    CustomersTableFAX: TStringField;
    CustomersTableTaxRate: TFloatField;
    CustomersTableContact: TStringField;
    CustomersTableLastInvoiceDate: TDateTimeField;
    ExecuteBtn: TButton;
    OrdersTableOrderNo: TFloatField;
    OrdersTableCustNo: TFloatField;
    OrdersTableSaleDate: TDateTimeField;
    OrdersTableShipDate: TDateTimeField;
    OrdersTableEmpNo: TIntegerField;
    OrdersTableShipToContact: TStringField;
    OrdersTableShipToAddr1: TStringField;
    OrdersTableShipToAddr2: TStringField;
    OrdersTableShipToCity: TStringField;
    OrdersTableShipToState: TStringField;
    OrdersTableShipToZip: TStringField;
    OrdersTableShipToCountry: TStringField;
    OrdersTableShipToPhone: TStringField;
    OrdersTableShipVIA: TStringField;
    OrdersTablePO: TStringField;
    OrdersTableTerms: TStringField;
    OrdersTablePaymentMethod: TStringField;
    OrdersTableItemsTotal: TCurrencyField;
    OrdersTableTaxRate: TFloatField;
    OrdersTableFreight: TCurrencyField;
    OrdersTableAmountPaid: TCurrencyField;
    TablesBtn: TButton;
    FieldsBtn: TButton;
    ColorsBtn: TButton;
    FilterBtn: TButton;
    SortBtn: TButton;
    LookupBtn: TButton;
    SelectBtn: TButton;
    GroupBtn: TButton;
    EditBtn: TButton;
    JoinsBtn: TButton;
    BooBtn: TButton;
    LoadBtn: TButton;
    StoreBtn: TButton;
    CloseBtn: TButton;
    procedure FormCreate(Sender: TObject);
    procedure FilterBtnClick(Sender: TObject);
    procedure LookupBtnClick(Sender: TObject);
    procedure SortBtnClick(Sender: TObject);
    procedure FieldsBtnClick(Sender: TObject);
    procedure ColorsBtnClick(Sender: TObject);
    procedure TablesBtnClick(Sender: TObject);
    procedure SelectBtnClick(Sender: TObject);
    procedure ExecuteBtnClick(Sender: TObject);
    procedure GroupBtnClick(Sender: TObject);
    procedure EditBtnClick(Sender: TObject);
    procedure JoinsBtnClick(Sender: TObject);
    procedure LoadBtnClick(Sender: TObject);
    procedure StoreBtnClick(Sender: TObject);
    procedure CloseBtnClick(Sender: TObject);
    procedure BooBtnClick(Sender: TObject);
  private
    QueryInfo: TQueryInfo;
    Formatter: TQIFormatter;
    SelectDlg: TQISelectDialog;
    FilterDlg: TQIFilterDialog;
    LookupDlg: TQILookupDialog;
    SortDlg:   TQIOrderDialog;
    GroupDlg:  TQIGroupDialog;
    EditDlg:   TMemoDialog;
    QueryWdw:  TQIQueryWindow;
    Archiver:  TQIArchiver;
    procedure UpdateBtns;
    procedure SetQuery;
    procedure GetQueryScript(Sender: TObject; Strings: TStrings);
  end;

var
  TestForm: TTestForm;

implementation

{$R *.DFM}

procedure TTestForm.FormCreate(Sender: TObject);
begin
  QueryInfo := TQueryInfo.Create(Self);
  with QueryInfo do begin
    DatabaseName := 'DBDEMOS';
    Tables.AddFrom('CUSTOMER.DB', 'Customers', CustomersTable);
    Tables.AddFrom('ORDERS.DB', 'Orders', OrdersTable);
    with Fields do begin
      AddFromField(CustomersTableCustNo).UserName := 'Customer#';
      AddFromField(CustomersTableCompany);
      AddFromField(CustomersTableAddr1).UserName := 'Address';
      AddFromField(CustomersTableCity);
      AddFromField(OrdersTableOrderNo).UserName := 'Order#';
      AddFromField(OrdersTableCustNo).FieldUsage := [];     {only for join}
      AddFromField(OrdersTableAmountPaid);
      AddFrom('AdjAmount', 'Adjusted Amount', 'ORDERS.AmountPaid * 0.8', Tables[1],
        ftCurrency, [fuSelect, fuCalc, fuFilter, fuGroup, fuOrder, fuLookup], nil);
      AddFromField(OrdersTablePaymentMethod);
      AddFromField(OrdersTableSaleDate);
    end;
    Joins.AddFrom(Fields[0], Fields[5], qoEquals);
  end;
  Formatter := TQIFormatter.Create(Self);
  Formatter.QueryInfo := Self.QueryInfo;
  SelectDlg := TQISelectDialog.Create(Self);
  SelectDlg.QueryInfo := Self.QueryInfo;
  SelectDlg.OnGrouping := GroupBtnClick;
  FilterDlg := TQIFilterDialog.Create(Self);
  FilterDlg.QueryInfo := Self.QueryInfo;
  FilterDlg.OnOrdering := SortBtnClick;
  LookupDlg := TQILookupDialog.Create(Self);
  LookupDlg.QueryInfo := Self.QueryInfo;
  SortDlg := TQIOrderDialog.Create(Self);
  SortDlg.QueryInfo := QueryInfo;
  SortDlg.AscArrowColor := clBlue;
  GroupDlg := TQIGroupDialog.Create(Self);
  GroupDlg.QueryInfo := QueryInfo;
  EditDlg := TMemoDialog.Create(Self);
  EditDlg.Caption := 'SQL Script Editor';
  QueryWdw := TQIQueryWindow.Create(Self);
  with QueryWdw do begin
    QueryInfo := Self.QueryInfo;
    RequestLive := True;
{   OnSelect := SelectBtnClick;
    OnFilter := FilterBtnClick;
    OnOrder  := SortBtnClick;
    OnEditSql := EditBtnClick;
    OnLoad := EditBtnClick;
    OnSave := EditBtnClick;
    OnLookup := EditBtnClick;
    OnFindNext := EditBtnClick;
    OnPrint := EditBtnClick;
    OnReport := EditBtnClick;}
  end;
  Archiver := TQIArchiver.Create(Self);
  with Archiver do begin
    QueryInfo := Self.QueryInfo;
    KeepOpen := True;
    if AutoCreate and not FileExists(ArchivePath + 'qiQuery.db') then
      CreateTables;
  end;
  UpdateBtns;
  SetQuery;
end;

procedure TTestForm.FieldsBtnClick(Sender: TObject);
begin
  if EditFields(QueryInfo) then UpdateBtns;
end;

procedure TTestForm.TablesBtnClick(Sender: TObject);
begin
  EditTables(QueryInfo);
end;

procedure TTestForm.JoinsBtnClick(Sender: TObject);
begin
  EditJoins(QueryInfo);
end;

procedure TTestForm.SelectBtnClick(Sender: TObject);
begin
  if SelectDlg.Execute then SetQuery;
end;

procedure TTestForm.FilterBtnClick(Sender: TObject);
begin
  if FilterDlg.Execute then SetQuery;
end;

procedure TTestForm.SortBtnClick(Sender: TObject);
begin
  if SortDlg.Execute then SetQuery;
end;

procedure TTestForm.GroupBtnClick(Sender: TObject);
begin
  if GroupDlg.Execute then SetQuery;
end;

procedure TTestForm.EditBtnClick(Sender: TObject);
begin
  EditDlg.Execute(SQLMemo.Lines);
end;

procedure TTestForm.LookupBtnClick(Sender: TObject);
begin
  if LookupDlg.Execute then
    with QueryInfo.Fields.Lookup do begin
      LookupValueEdit.Text := Value;
      LookupFieldEdit.Text := Field.SQLName;
    end;
end;

procedure TTestForm.LoadBtnClick(Sender: TObject);
begin
  if Archiver.Load then SetQuery;
end;

procedure TTestForm.StoreBtnClick(Sender: TObject);
begin
  Archiver.Store('', UserMemo.Lines);
end;

procedure TTestForm.CloseBtnClick(Sender: TObject);
begin
  Close;
end;

procedure TTestForm.BooBtnClick(Sender: TObject);
begin
  ShowMessage('Boo!');
end;

procedure TTestForm.ColorsBtnClick(Sender: TObject);
begin
  FilterColorsForm := TFilterColorsForm.Create(Self);
  with FilterColorsForm do
  try
    Colors := FilterDlg.Colors;
    ShowModal;
  finally
    Free;
  end;
end;

procedure TTestForm.ExecuteBtnClick(Sender: TObject);
begin
  with QueryWdw do begin
    SQLScript := SQLMemo.Lines;
    DisplayScript := UserMemo.Lines;
    Show;
    ExecuteQuery;
  end;
end;

procedure TTestForm.GetQueryScript(Sender: TObject; Strings: TStrings);
begin
end;

procedure TTestForm.UpdateBtns;
begin
  FilterBtn.Enabled := QueryInfo.Fields.Count > 0;
  LookupBtn.Enabled := FilterBtn.Enabled;
  SortBtn.Enabled   := FilterBtn.Enabled;
end;

procedure TTestForm.SetQuery;
begin
  Formatter.BuildSQLQuery(SQLMemo.Lines);
  Formatter.BuildUserQuery(UserMemo.Lines);
  UpdateBtns;
end;

end.
